Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Manager ¶
type Manager interface {
// ValidateBackend validates that backend configuration is correct
ValidateBackend(ctx context.Context, mesh string, backend mesh_proto.CertificateAuthorityBackend) error
// Ensure ensures that CA of given name is available
Ensure(ctx context.Context, mesh string, backend mesh_proto.CertificateAuthorityBackend) error
// UsedSecrets returns a list of secrets that are used by the manager
UsedSecrets(mesh string, backend mesh_proto.CertificateAuthorityBackend) ([]string, error)
// GetRootCert returns root certificates of the CA
GetRootCert(ctx context.Context, mesh string, backend mesh_proto.CertificateAuthorityBackend) ([]Cert, error)
// GenerateDataplaneCert generates cert for a dataplane with service tags
GenerateDataplaneCert(ctx context.Context, mesh string, backend mesh_proto.CertificateAuthorityBackend, services []string) (KeyPair, error)
}
Manager manages CAs by creating CAs and generating certificate. It is created per CA type and then may be used for different CA instances of the same type
Click to show internal directories.
Click to hide internal directories.